==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/IdentityProviderPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.IdentityProviderPolicyProvider;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdentityProviderPolicyRuleCondition
 */
@JsonPropertyOrder({ IdentityProviderPolicyRuleCondition.JSON_PROPERTY_IDP_IDS,
        IdentityProviderPolicyRuleCondition.JSON_PROPERTY_PROVIDER })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class IdentityProviderPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_IDP_IDS = "idpIds";
    private List<String> idpIds = null;

    public static final String JSON_PROPERTY_PROVIDER = "provider";
    private IdentityProviderPolicyProvider provider;

    public IdentityProviderPolicyRuleCondition() {
    }

    public IdentityProviderPolicyRuleCondition idpIds(List<String> idpIds) {

        this.idpIds = idpIds;
        return this;
    }

    public IdentityProviderPolicyRuleCondition addidpIdsItem(String idpIdsItem) {
        if (this.idpIds == null) {
            this.idpIds = new ArrayList<>();
        }
        this.idpIds.add(idpIdsItem);
        return this;
    }

    /**
     * Get idpIds
     *
     * @return idpIds
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_IDP_IDS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getIdpIds() {
        return idpIds;
    }

    @JsonProperty(JSON_PROPERTY_IDP_IDS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setIdpIds(List<String> idpIds) {
        this.idpIds = idpIds;
    }

    public IdentityProviderPolicyRuleCondition provider(IdentityProviderPolicyProvider provider) {

        this.provider = provider;
        return this;
    }

    /**
     * Get provider
     *
     * @return provider
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROVIDER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public IdentityProviderPolicyProvider getProvider() {
        return provider;
    }

    @JsonProperty(JSON_PROPERTY_PROVIDER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProvider(IdentityProviderPolicyProvider provider) {
        this.provider = provider;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdentityProviderPolicyRuleCondition identityProviderPolicyRuleCondition = (IdentityProviderPolicyRuleCondition) o;
        return Objects.equals(this.idpIds, identityProviderPolicyRuleCondition.idpIds)
                && Objects.equals(this.provider, identityProviderPolicyRuleCondition.provider);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(idpIds, provider);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdentityProviderPolicyRuleCondition {\n");
        sb.append("    idpIds: ").append(toIndentedString(idpIds)).append("\n");
        sb.append("    provider: ").append(toIndentedString(provider)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/IdentityProviderPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.IdentityProviderPolicyProvider;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdentityProviderPolicyRuleCondition
 */
@JsonPropertyOrder({ IdentityProviderPolicyRuleCondition.JSON_PROPERTY_IDP_IDS,
        IdentityProviderPolicyRuleCondition.JSON_PROPERTY_PROVIDER })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class IdentityProviderPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_IDP_IDS = "idpIds";
    private List<String> idpIds = null;

    public static final String JSON_PROPERTY_PROVIDER = "provider";
    private IdentityProviderPolicyProvider provider;

    public IdentityProviderPolicyRuleCondition() {
    }

    public IdentityProviderPolicyRuleCondition idpIds(List<String> idpIds) {

        this.idpIds = idpIds;
        return this;
    }

    public IdentityProviderPolicyRuleCondition addidpIdsItem(String idpIdsItem) {
        if (this.idpIds == null) {
            this.idpIds = new ArrayList<>();
        }
        this.idpIds.add(idpIdsItem);
        return this;
    }

    /**
     * Get idpIds
     *
     * @return idpIds
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_IDP_IDS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getIdpIds() {
        return idpIds;
    }

    @JsonProperty(JSON_PROPERTY_IDP_IDS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setIdpIds(List<String> idpIds) {
        this.idpIds = idpIds;
    }

    public IdentityProviderPolicyRuleCondition provider(IdentityProviderPolicyProvider provider) {

        this.provider = provider;
        return this;
    }

    /**
     * Get provider
     *
     * @return provider
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROVIDER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public IdentityProviderPolicyProvider getProvider() {
        return provider;
    }

    @JsonProperty(JSON_PROPERTY_PROVIDER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProvider(IdentityProviderPolicyProvider provider) {
        this.provider = provider;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdentityProviderPolicyRuleCondition identityProviderPolicyRuleCondition = (IdentityProviderPolicyRuleCondition) o;
        return Objects.equals(this.idpIds, identityProviderPolicyRuleCondition.idpIds)
                && Objects.equals(this.provider, identityProviderPolicyRuleCondition.provider);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(idpIds, provider);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdentityProviderPolicyRuleCondition {\n");
        sb.append("    idpIds: ").append(toIndentedString(idpIds)).append("\n");
        sb.append("    provider: ").append(toIndentedString(provider)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
